==> hydrogen-1.2.3-1.1-x86_64.pkg.tar.zst: usr/include/hydrogen/config.h <==
#ifndef HYD_CONFIG_H
#define HYD_CONFIG_H

#include <string>

#ifndef QT_BEGIN_NAMESPACE
#    define QT_BEGIN_NAMESPACE
#endif

#ifndef QT_END_NAMESPACE
#    define QT_END_NAMESPACE
#endif

#define H2_USR_PATH ".hydrogen"
#define H2_SYS_PATH "/usr/share/hydrogen"
#define CONFIG_PREFIX "/usr"

#define H2CORE_VERSION_MAJOR 1
#define H2CORE_VERSION_MINOR 2
#define H2CORE_VERSION_PATCH 3

#define H2CORE_GIT_REVISION 
#define H2CORE_VERSION "1.2.3"
#define H2CORE_IS_DEVEL_BUILD false


#define MAX_INSTRUMENTS 1000
#define MAX_COMPONENTS  32
#define MAX_NOTES       192
#define MAX_FX          4
#define MAX_BUFFER_SIZE 8192

#define HAVE_SSCANF
#define HAVE_RTCLOCK
#define HAVE_JACK_PORT_RENAME
#define HAVE_EXECINFO_H

#ifndef H2CORE_HAVE_DEBUG
/* #undef H2CORE_HAVE_DEBUG */
#endif
#ifndef H2CORE_HAVE_BUNDLE
/* #undef H2CORE_HAVE_BUNDLE */
#endif
#ifndef H2CORE_HAVE_APPIMAGE
/* #undef H2CORE_HAVE_APPIMAGE */
#endif
#ifndef H2CORE_HAVE_DYNAMIC_JACK_CHECK
/* #undef H2CORE_HAVE_DYNAMIC_JACK_CHECK */
#endif
#ifndef H2CORE_HAVE_LIBSNDFILE
#define H2CORE_HAVE_LIBSNDFILE
#endif
#ifndef H2CORE_HAVE_LIBARCHIVE
#define H2CORE_HAVE_LIBARCHIVE
#endif
#ifndef H2CORE_HAVE_OSS
/* #undef H2CORE_HAVE_OSS */
#endif
#ifndef H2CORE_HAVE_ALSA
#define H2CORE_HAVE_ALSA
#endif
#ifndef H2CORE_HAVE_JACK
#define H2CORE_HAVE_JACK
#endif
#ifndef H2CORE_HAVE_LASH
/* #undef H2CORE_HAVE_LASH */
#endif
#ifndef H2CORE_HAVE_OSC
#define H2CORE_HAVE_OSC
#endif
#ifndef H2CORE_HAVE_PORTAUDIO
#define H2CORE_HAVE_PORTAUDIO
#endif
#ifndef H2CORE_HAVE_PORTMIDI
#define H2CORE_HAVE_PORTMIDI
#endif
#ifndef H2CORE_HAVE_COREAUDIO
/* #undef H2CORE_HAVE_COREAUDIO */
#endif
#ifndef H2CORE_HAVE_COREMIDI
/* #undef H2CORE_HAVE_COREMIDI */
#endif
#ifndef H2CORE_HAVE_PULSEAUDIO
#define H2CORE_HAVE_PULSEAUDIO
#endif
#ifndef H2CORE_HAVE_LRDF
#define H2CORE_HAVE_LRDF
#endif
#ifndef H2CORE_HAVE_LADSPA
#define H2CORE_HAVE_LADSPA
#endif
#ifndef H2CORE_HAVE_RUBBERBAND
/* #undef H2CORE_HAVE_RUBBERBAND */
#endif

#endif

==> hydrogen-1.2.5-1-x86_64.pkg.tar.zst: usr/include/hydrogen/config.h <==
#ifndef HYD_CONFIG_H
#define HYD_CONFIG_H

#include <string>

#ifndef QT_BEGIN_NAMESPACE
#    define QT_BEGIN_NAMESPACE
#endif

#ifndef QT_END_NAMESPACE
#    define QT_END_NAMESPACE
#endif

#define H2_USR_PATH ".hydrogen"
#define H2_SYS_PATH "/usr/share/hydrogen"
#define CONFIG_PREFIX "/usr"

#define H2CORE_VERSION_MAJOR 1
#define H2CORE_VERSION_MINOR 2
#define H2CORE_VERSION_PATCH 5

#define H2CORE_GIT_REVISION 
#define H2CORE_VERSION "1.2.5-"
#define H2CORE_IS_DEVEL_BUILD true


#define MAX_INSTRUMENTS 1000
#define MAX_COMPONENTS  32
#define MAX_NOTES       192
#define MAX_FX          4
#define MAX_BUFFER_SIZE 8192

#define HAVE_SSCANF
#define HAVE_RTCLOCK
#define HAVE_JACK_PORT_RENAME
#define HAVE_EXECINFO_H

#ifndef H2CORE_HAVE_DEBUG
/* #undef H2CORE_HAVE_DEBUG */
#endif
#ifndef H2CORE_HAVE_QT6
/* #undef H2CORE_HAVE_QT6 */
#endif
#ifndef H2CORE_HAVE_BUNDLE
/* #undef H2CORE_HAVE_BUNDLE */
#endif
#ifndef H2CORE_HAVE_APPIMAGE
/* #undef H2CORE_HAVE_APPIMAGE */
#endif
#ifndef H2CORE_HAVE_DYNAMIC_JACK_CHECK
/* #undef H2CORE_HAVE_DYNAMIC_JACK_CHECK */
#endif
#ifndef H2CORE_HAVE_LIBSNDFILE
#define H2CORE_HAVE_LIBSNDFILE
#endif
#ifndef H2CORE_HAVE_FLAC_SUPPORT
#define H2CORE_HAVE_FLAC_SUPPORT
#endif
#ifndef H2CORE_HAVE_OPUS_SUPPORT
#define H2CORE_HAVE_OPUS_SUPPORT
#endif
#ifndef H2CORE_HAVE_MP3_SUPPORT
#define H2CORE_HAVE_MP3_SUPPORT
#endif
#ifndef H2CORE_HAVE_LIBARCHIVE
#define H2CORE_HAVE_LIBARCHIVE
#endif
#ifndef H2CORE_HAVE_OSS
/* #undef H2CORE_HAVE_OSS */
#endif
#ifndef H2CORE_HAVE_ALSA
#define H2CORE_HAVE_ALSA
#endif
#ifndef H2CORE_HAVE_JACK
#define H2CORE_HAVE_JACK
#endif
#ifndef H2CORE_HAVE_LASH
/* #undef H2CORE_HAVE_LASH */
#endif
#ifndef H2CORE_HAVE_OSC
#define H2CORE_HAVE_OSC
#endif
#ifndef H2CORE_HAVE_PORTAUDIO
#define H2CORE_HAVE_PORTAUDIO
#endif
#ifndef H2CORE_HAVE_PORTMIDI
#define H2CORE_HAVE_PORTMIDI
#endif
#ifndef H2CORE_HAVE_COREAUDIO
/* #undef H2CORE_HAVE_COREAUDIO */
#endif
#ifndef H2CORE_HAVE_COREMIDI
/* #undef H2CORE_HAVE_COREMIDI */
#endif
#ifndef H2CORE_HAVE_PULSEAUDIO
#define H2CORE_HAVE_PULSEAUDIO
#endif
#ifndef H2CORE_HAVE_LRDF
#define H2CORE_HAVE_LRDF
#endif
#ifndef H2CORE_HAVE_LADSPA
#define H2CORE_HAVE_LADSPA
#endif
#ifndef H2CORE_HAVE_RUBBERBAND
/* #undef H2CORE_HAVE_RUBBERBAND */
#endif
#ifndef HAVE_INTEGRATION_TESTS
/* #undef HAVE_INTEGRATION_TESTS */
#endif

#endif
